annotateGenes Annotate genes with genomic coordinates with reference to hg38 using Ensembl based annotation package
Source:R/preProcessing.R
annotateGenes.RdannotateGenes Annotate genes with genomic coordinates with reference to hg38 using Ensembl based annotation package