Skip to contents

annoteBandOncoHeat Annotate with chromosome bands the data frame with difference copy number alterations between subclones

Usage

annoteBandOncoHeat(mtx_annot, diffSub, nSub, organism = "human")

Arguments

mtx_annot

Annotation matrix

diffSub

Data frame with difference copy number alterations between subclones

nSub

Number of subclones

organism

Organism to be analysed (default = "human")