computeCNAmtx computed the CNA matrix using the break points obtained from segmentation
Source:R/classifyTumor.R
computeCNAmtx.RdcomputeCNAmtx computed the CNA matrix using the break points obtained from segmentation
R/classifyTumor.R
computeCNAmtx.RdcomputeCNAmtx computed the CNA matrix using the break points obtained from segmentation