Skip to contents

This function extracts the raw count matrix from a Seurat object, supporting both Seurat V4 and V5 data structures. It prioritizes V4 format.

Usage

getCountMtxFromSeurat(seurat_obj, assay = "RNA", layer = "counts")

Arguments

seurat_obj

A Seurat object

assay

Assay name to use (default "RNA")

layer

Layer name for Seurat V5 (default "counts")

Value

Raw count matrix with genes on rows and cells on columns

Examples

if (FALSE) { # \dontrun{
count_mtx <- getCountMtxFromSeurat(seurat_obj)
results <- pipelineCNA(count_mtx)
} # }