pipelineCNA Executes the entire SCEVAN pipeline that classifies tumour and normal cells from the raw count matrix, infer the clonal profile of cancer cells and looks for possible sub-clones in the tumour cell matrix automatically analysing the specific and shared alterations of each subclone and a differential analysis of pathways and genes expressed in each subclone.
Source:R/pipelineCNA.R
pipelineCNA.RdpipelineCNA Executes the entire SCEVAN pipeline that classifies tumour and normal cells from the raw count matrix, infer the clonal profile of cancer cells and looks for possible sub-clones in the tumour cell matrix automatically analysing the specific and shared alterations of each subclone and a differential analysis of pathways and genes expressed in each subclone.
Usage
pipelineCNA(
count_mtx,
sample = "",
par_cores = 20,
norm_cell = NULL,
SUBCLONES = TRUE,
beta_vega = 0.5,
ClonalCN = TRUE,
plotTree = TRUE,
AdditionalGeneSets = NULL,
SCEVANsignatures = TRUE,
organism = "human",
ngenes_chr = 5,
perc_genes = 10,
FIXED_NORMAL_CELLS = FALSE,
output_dir = "./output"
)Arguments
- count_mtx
Raw count matrix with genes on rows (both Gene Symbol or Ensembl ID are allowed) and cells on columns.
- sample
Sample name to save results (optional)
- par_cores
Number of cores to run the pipeline (optional - default 20)
- norm_cell
Vector of possible known normal cells to be used as confident normal cells (optional)
- SUBCLONES
Boolean value TRUE if you are interested in analysing the clonal structure and FALSE if you are only interested in the classification of malignant and non-malignant cells (optional - default TRUE)
- beta_vega
Specifies beta parameter for segmentation, higher beta for more coarse-grained segmentation. (optional - default 0.5)
- ClonalCN
Get clonal CN profile inference from all tumour cells (optional)
- plotTree
Plot Phylogenetic tree (optional - default FALSE)
- AdditionalGeneSets
list of additional signatures of normal cell types (optional)
- SCEVANsignatures
FALSE if you only want to use only the signatures specified in AdditionalGeneSets (default TRUE)
- organism
Organism to be analysed (optional - "mouse" or "human" - default "human")
- ngenes_chr
Minimum number of genes expressed on chromosome (optional - default 5)
- perc_genes
Minimum percentage gene expressed in each cell (optional - default 10)
- FIXED_NORMAL_CELLS
TRUE if norm_cell vector to be used as fixed reference, if you are only interested in clonal structure and not normal/tumor classification (default FALSE)