Skip to contents

plotAllSubclonalCN Plot the copy number of each subclone of a sample.

Usage

plotAllSubclonalCN(sample, pathOutput = "./output/")

Arguments

sample

Name of the sample.

pathOutput

Path to the output folder containing the output of pipelineCNA.