plotCNA_withAnnotCells allows generating a heatmap of the copy number profile of each cell, adding cell annotations as tracks on the heatmap.
Source:R/plotHeatmap.R
plotCNA_withAnnotCells.RdplotCNA_withAnnotCells allows generating a heatmap of the copy number profile of each cell, adding cell annotations as tracks on the heatmap.
Usage
plotCNA_withAnnotCells(
SampleName,
metadata,
COLUMNS_TO_PLOT,
outputPATH = "./output/",
SUBCLONE = FALSE,
hcc = NULL,
plotNAME = "heatmap_with_annotation.png",
par_cores = 20
)Arguments
- SampleName
Sample name used in pipelineCNA
- metadata
data.frame cells (rownames) and annotations (columns)
- COLUMNS_TO_PLOT
columns of metadata to be added as tracks in the heatmap
- outputPATH
output folder of pipelineCNA (optional)
- SUBCLONE
Boolean value TRUE if you are interested in CNA matrix of sublclone and FALSE if you are interested in CNA matrix of all cells.
- hcc
if you have previously computed clustering for the heatmap (optional - default 0.5)
- plotNAME
name file to save the figure (optional)
- par_cores
number of cores used for clustering (optional - default 20)
Examples
if (FALSE) { # \dontrun{
plotCNA_withAnnotCells(SampleName, metadata, c("CellType","Tissue","Cluster"))
} # }