Skip to contents

preprocessingMtx Pre-processing steps: Cells with less than 200 genes and the genes expressed in less than 1 according to genomic coordinates. Highly confident normal cells are sought in the matrix. Genes involved in the cell cycle pathway are removed. Log-Freeman–Tukey transformation to stabilize variance and a polynomial dynamic linear modeling (DLM) to smooth out the outliers.

Usage

preprocessingMtx(
  count_mtx,
  sample,
  ngenes_chr = 5,
  perc_genes = 0.1,
  par_cores = 20,
  findConfident = TRUE,
  AdditionalGeneSets = NULL,
  SCEVANsignatures = TRUE,
  organism = "human",
  output_dir = "./output"
)

Arguments

count_mtx

raw count matrix

ngenes_chr

minimum number of genes per chromosome (optional)

perc_genes

percentage of cells in which each gene is to be expressed (optional)

par_cores

number of cores (optional)

findConfident

Boolean value to search for normal cells (default TRUE)

AdditionalGeneSets

List of additional signatures to be used to search for normal cells (optional)

SCEVANsignatures

Boolean value TRUE to use internal SCEVAN signatures for normal cells or FALSE to use only signatures specified in AdditionalGeneSets (default TRUE)

SMOOTH

Boolean value to perform smoothing (optional)

Value

count_mtx_smooth processed and smoothed matrix count_mtx_annot annotated matrix

Examples

if (FALSE) { # \dontrun{
res <- preprocessingMtx(count_mtx, sample = "test")
} # }