classifyTumorCells Classify tumour and normal cells from the raw count matrix, using normal cells in the matrix or by subtracting a synthetic baseline from the matrix if there are no normal cells in the matrix.
Source:R/classifyTumor.R
classifyTumorCells.RdclassifyTumorCells Classify tumour and normal cells from the raw count matrix, using normal cells in the matrix or by subtracting a synthetic baseline from the matrix if there are no normal cells in the matrix.
Usage
classifyTumorCells(
count_mtx,
annot_mtx,
sample = "",
distance = "euclidean",
par_cores = 20,
ground_truth = NULL,
norm_cell_names = NULL,
SEGMENTATION_CLASS = TRUE,
SMOOTH = TRUE,
beta_vega = 0.5,
FIXED_NORMAL_CELLS = FALSE,
output_dir = "./output"
)Arguments
- count_mtx
raw count matrix
- annot_mtx
matrix containing the annotations of the genes (rows: genes, columns: chr start end)
- sample
sample name (optional)
- distance
distance used in hierarchical clustering (default euclidean)
- par_cores
number of cores (default 20)
- norm_cell_names
confident normal cells (optional)
- SEGMENTATION_CLASS
Boolean value to perform segmentation before classification (default TRUE)
- SMOOTH
Boolean value to perform smoothing (default TRUE)
- beta_vega
specifies beta parameter for segmentation, higher beta for more coarse-grained segmentation. (default 0.5)
- FIXED_NORMAL_CELLS
TRUE if vector of norm_cell to be used as reference fixed, if you are interested only in clonal structure e non nella classificazione normal/tumor (default FALSE)
- gr_truth
ground truth of classification (optional)