getBreaksVegaMC Get SCEVAN segmentation of the matrix.
Usage
getBreaksVegaMC(
mtx,
chr_vect,
sample = "",
beta_vega = 0.5,
output_dir = "./output"
)
Arguments
- mtx
count matrix
- chr_vect
Vector specifying for each gene the chromosome where it is located
- sample
sample name (optional)
- beta_vega
specifies beta parameter for segmentation, higher beta for more coarse-grained segmentation. (default 0.5)